@@ -618,54 +618,3 @@ class Workspace(Entity):
         import labstep.generic.entity.repository as entityRepository
 
         return entityRepository.editEntity(member, {"is_home": True})
-
-    def setAutosharing(
-        self, experiment_sharing=UNSPECIFIED, protocol_sharing=UNSPECIFIED, resource_sharing=UNSPECIFIED
-    ):
-        """
-        Parameters
-        ----------
-        experiment_sharing (str)
-            Automatically share experiments
-            you create and own with this workspace. Set to True or False
-
-        protocol_sharing (str)
-            Automatically share protocols
-            you create and own with this workspace. Set to True or False
-
-        resource_sharing (str)
-            Automatically share resources
-            you create and own with this workspace. Set to True or False
-
-        Returns
-        -------
-        :class:`~labstep.entities.autoshare.model.Autoshare`
-            An object representing the Autosharing policy.
-
-        Example
-        -------
-        ::
-
-            # Get an workspace
-            workspace = user.getWorkspaces(123)
-
-            workspace.setAutosharing(experiment_sharing='view')
-        """
-        self.update()
-
-        if self.security_policy is None:
-            import labstep.generic.entity.repository as entityRepository
-
-            policy = entityRepository.newEntity(
-                self.__user__,
-                Autoshare,
-                {"user_group_id": self.logged_user_user_group["id"]},
-            )
-        else:
-            policy = Autoshare(self.security_policy, self.__user__)
-
-        return policy.edit(
-            experiment_sharing=experiment_sharing,
-            protocol_sharing=protocol_sharing,
-            resource_sharing=resource_sharing,
-        )
